<?php
/**
 * ###############################################
 *
 * SWIFT Framework
 * _______________________________________________
 *
 * @author         Varun Shoor
 *
 * @package        SWIFT
 * @copyright      Copyright (c) 2001-2012, Kayako
 * @license        http://www.kayako.com/license
 * @link           http://www.kayako.com
 *
 * ###############################################
 */

/**
 * SugarCRM Fetch User Controller
 *
 * @author Rahul Bhattacharya
 */
class Controller_SugarCRMFetchUserMinute extends Controller_cron
{
	/**
	 * Responsible to retrieve the SugarCrm Contacts using the SugarCrm API
	 *
	 * @author Rahul Bhattacharya
	 * @return bool "true" on Success, "false" otherwise
	 * @throws SWIFT_Exception If the Class is not Loaded
	 */
	public function SugarCRMFetchUser()
	{
		$_SWIFT = SWIFT::GetInstance();

		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(SWIFT_CLASSNOTLOADED);
		}

		$this->Load->Library('SugarCRMRestAPI:SugarCRMRestAPIRequest');

		$_sugarcrmUsername = $_SWIFT->Settings->Get('sugarcrm_username');
		$_sugarcrmPassword = $_SWIFT->Settings->Get('sugarcrm_password');
		$_sugarcrmApiUrl   = $_SWIFT->Settings->Get('sugarcrm_apiurl');

		if (empty($_sugarcrmUsername) || empty($_sugarcrmPassword) || empty($_sugarcrmApiUrl)) {
			throw new SWIFT_Exception(SWIFT_INVALIDDATA);
		} else {
			$_sugarcrmSessionResponse = $this->SugarCRMRestAPIRequest->LoginRequest($_sugarcrmUsername, $_sugarcrmPassword, $_sugarcrmApiUrl);

			// Verify the login credentials for SugarCRM Rest API.
			if ($_sugarcrmSessionResponse == 'fail') {
				throw new SWIFT_Exception(SWIFT_INVALIDDATA);
			} else {
				$this->Load->Model('SugarCRMAccount:SugarCRMAccount');
				$this->Load->Model('SugarCRMAccount:SugarCRMUser');

				$_organizationList = $this->SugarCRMAccount->FetchOrganizations();
				foreach ($_organizationList as $_accountList) {
					//Sync sugar contacts with kayako user
					$_sugarcrmContactResponse = $this->SugarCRMRestAPIRequest->FetchContacts($_sugarcrmSessionResponse, $_sugarcrmApiUrl, $_accountList['accountid']);

					foreach ($_sugarcrmContactResponse->entry_list as $key => $value) {
						$_userDetails = array(
							'id'                 => $value->name_value_list->id->value,
							'userorganizationid' => $_accountList['parentaccountid'],
							'fullname'           => $value->name_value_list->name->value,
							'email'              => $value->name_value_list->email1->value,
							'phone'              => $value->name_value_list->phone_work->value,
							'userdesignation'    => $value->name_value_list->title->value,
							'dateline'           => time(),
						);

						$this->SugarCRMUser->InsertUsers($_userDetails);
					}
				}
			}
		}

		if (!SWIFT::Get('iscron'))
		{
			$_SWIFT_CronObject = SWIFT_Cron::Retrieve('SugarCRMAccountListing');
			SWIFT_CronLog::Create($_SWIFT_CronObject, '');
		}

		return true;
	}
}