<?php
/**
 * ###############################################
 *
 * SWIFT Framework
 * _______________________________________________
 *
 * @author         Varun Shoor
 *
 * @package        SWIFT
 * @copyright      Copyright (c) 2001-2012, Kayako
 * @license        http://www.kayako.com/license
 * @link           http://www.kayako.com
 *
 * ###############################################
 */

/**
 * SugarCRM Ticket Lead Mapping
 *
 * @author Rahul Bhattacharya
 */
class SWIFT_SugarCRMTicketLeadMap extends SWIFT_Model
{
	const TABLE_NAME  = 'sugarcrmticketleadmap';
	const PRIMARY_KEY = 'sugarcrmticketleadmapid';

	const TABLE_STRUCTURE = "sugarcrmticketleadmapid I PRIMARY AUTO NOTNULL,
							 kayakoticketid I DEFAULT 0 NOTNULL,
                             sugarcrmleadid C(255) DEFAULT '' NOTNULL";

	const INDEX_1	=	'kayakoaccountid';
	const INDEX_2	=	'sugarcrmleadid';

	/**
	 * Insert ticket lead map info
	 *
	 * @author Rahul Bhattacharya
	 * @param int $_kayakoTicketId Kayako Ticket Id
	 * @param int $_sugarCRMLeadId SugarCRM Lead Id
	 * @return bool "true
	 * @throws SWIFT_Exception If the Class is not Loaded
	 */
	public function InsertLead($_kayakoTicketId, $_sugarCRMLeadId)
	{
		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(__CLASS__ . ':  ' . SWIFT_CLASSNOTLOADED);
		}

		$_SWIFT = SWIFT::GetInstance();

		if (empty($_sugarCRMLeadId) || empty($_kayakoTicketId))
		{
			throw new SWIFT_Exception(SWIFT_INVALIDDATA);
		}

		$_fields = array();
		$_fields['kayakoticketid'] = $_SWIFT->Database->Escape($_kayakoTicketId);
		$_fields['sugarcrmleadid'] = $_SWIFT->Database->Escape($_sugarCRMLeadId);

		$_SWIFT->Database->AutoExecute(TABLE_PREFIX . self::TABLE_NAME, $_fields, 'INSERT');

		return true;
	}

	/**
	 * Get SugarCRM lead id
	 *
	 * @author Rahul Bhattacharya
	 * @param int $_kayakoTicketId Ticket Id
	 * @return bool "true" on Success, "false" otherwise
	 * @throws SWIFT_Exception If invalid data provided
	 */
	public function GetLeadId($_kayakoTicketId)
	{
		$_SWIFT = SWIFT::GetInstance();

		if (empty($_kayakoTicketId))
		{
			throw new SWIFT_Exception(SWIFT_INVALIDDATA);
		}

		$_result = $_SWIFT->Database->QueryFetch("SELECT sugarcrmleadid FROM " . TABLE_PREFIX . self::TABLE_NAME . " WHERE kayakoticketid = '" . $_kayakoTicketId . "'");

		if ($_result)
		{
			return $_result['sugarcrmleadid'];
		}

		return false;
	}
}